package com.ruoyi.ems.report.service;

import java.util.List;

import com.ruoyi.ems.report.domain.EmsReportPointDnb;

/**
 * 电整点数据Service接口
 *
 * @author Yinq
 * @date 2024-05-22
 */
public interface IEmsReportPointDnbService {
    /**
     * 查询电整点数据
     *
     * @param objId 电整点数据主键
     * @return 电整点数据
     */
    public EmsReportPointDnb selectEmsReportPointDnbByObjId(Long objId);

    /**
     * 查询电整点数据列表
     *
     * @param emsReportPointDnb 电整点数据
     * @return 电整点数据集合
     */
    public List<EmsReportPointDnb> selectEmsReportPointDnbList(EmsReportPointDnb emsReportPointDnb);

    /**
     * 新增电整点数据
     *
     * @param emsReportPointDnb 电整点数据
     * @return 结果
     */
    public int insertEmsReportPointDnb(EmsReportPointDnb emsReportPointDnb);

    /**
     * 修改电整点数据
     *
     * @param emsReportPointDnb 电整点数据
     * @return 结果
     */
    public int updateEmsReportPointDnb(EmsReportPointDnb emsReportPointDnb);

    /**
     * 批量删除电整点数据
     *
     * @param objIds 需要删除的电整点数据主键集合
     * @return 结果
     */
    public int deleteEmsReportPointDnbByObjIds(Long[] objIds);

    /**
     * 删除电整点数据信息
     *
     * @param objId 电整点数据主键
     * @return 结果
     */
    public int deleteEmsReportPointDnbByObjId(Long objId);
}
